package com.ruoyi.web.controller.dhc;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.DhcArea;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dhc.service.IDhcAreaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 区域Controller
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
@RestController
@RequestMapping("/dhc/area")
public class DhcAreaController extends BaseController
{
    @Autowired
    private IDhcAreaService dhcAreaService;

    /**
     * 查询区域列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcArea dhcArea)
    {
        startPage();
        List<DhcArea> list = dhcAreaService.selectDhcAreaList(dhcArea);
        return getDataTable(list);
    }

    /**
     * 导出区域列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:export')")
    @Log(title = "区域", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcArea dhcArea)
    {
        List<DhcArea> list = dhcAreaService.selectDhcAreaList(dhcArea);
        ExcelUtil<DhcArea> util = new ExcelUtil<DhcArea>(DhcArea.class);
        util.exportExcel(response, list, "区域数据");
    }

    /**
     * 获取区域详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:query')")
    @GetMapping(value = "/{areaId}")
    public AjaxResult getInfo(@PathVariable("areaId") Long areaId)
    {
        return success(dhcAreaService.selectDhcAreaByAreaId(areaId));
    }

    /**
     * 新增区域
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:add')")
    @Log(title = "区域", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcArea dhcArea)
    {
        if (dhcArea.getAreaId() != null && dhcArea.getAreaId() == 0L) {
            dhcArea.setAreaId(null);
        }
        Integer count = dhcAreaService.insertDhcArea(dhcArea);
        if (count == -1) {
            return AjaxResult.error("区域编号已存在");
        } else {
            return AjaxResult.success();
        }
    }

    /**
     * 修改区域
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:edit')")
    @Log(title = "区域", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcArea dhcArea)
    {
        Integer count = dhcAreaService.updateDhcArea(dhcArea);
        if (count == -1) {
            return AjaxResult.error("区域编号已存在");
        } else {
            return AjaxResult.success();
        }
    }

    /**
     * 删除区域
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:remove')")
	@GetMapping("/del/{areaId}")
    public AjaxResult remove(@PathVariable("areaId") Long areaId)
    {
        Integer count = dhcAreaService.deleteDhcAreaByAreaId(areaId);
        if (count == -1) {
            return AjaxResult.error("该区域存在子区域，请先删除子区域");
        } else {
            return AjaxResult.success();
        }
    }
    /**
     * 查询区域信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:list')")
    @GetMapping("/queryArealist")
    public List<DhcArea> queryArealist(DhcArea dhcArea)
    {
        return dhcAreaService.selectDhcAreaList(dhcArea);
    }
    /**
     * 获取区域树列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:list')")
    @GetMapping("/areaTree")
    public AjaxResult areaTree(DhcArea area)
    {
        return success(dhcAreaService.selectAreaTreeList(area));
    }

    /**
     * 查询区域信息
     */
    @GetMapping("/queryAreaMaplist")
    public List<Map<String, String>>queryAreaMaplist(DhcArea dhcArea)
    {
        List<DhcArea> list = dhcAreaService.selectDhcAreaList(dhcArea);
        List<Map<String, String>> mapList = new ArrayList<>();
        for (DhcArea model : list) {
            Map<String, String> map = new HashMap<>();
            map.put("value", model.getAreaCode());
            map.put("label", model.getAreaName());
            mapList.add(map);
        }
        return mapList;
    }
}
