package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcBrand;
import com.ruoyi.dhc.service.IDhcBrandService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 品牌Controller
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
@RestController
@RequestMapping("/dhc/brand")
public class DhcBrandController extends BaseController
{
    @Autowired
    private IDhcBrandService dhcBrandService;

    /**
     * 查询品牌列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:brand:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcBrand dhcBrand)
    {
        startPage();
        List<DhcBrand> list = dhcBrandService.selectDhcBrandList(dhcBrand);
        return getDataTable(list);
    }

    /**
     * 导出品牌列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:brand:export')")
    @Log(title = "品牌", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcBrand dhcBrand)
    {
        List<DhcBrand> list = dhcBrandService.selectDhcBrandList(dhcBrand);
        ExcelUtil<DhcBrand> util = new ExcelUtil<DhcBrand>(DhcBrand.class);
        util.exportExcel(response, list, "品牌数据");
    }

    /**
     * 获取品牌详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:brand:query')")
    @GetMapping(value = "/{brandId}")
    public AjaxResult getInfo(@PathVariable("brandId") Long brandId)
    {
        return success(dhcBrandService.selectDhcBrandByBrandId(brandId));
    }

    /**
     * 新增品牌
     */
    @PreAuthorize("@ss.hasPermi('dhc:brand:add')")
    @Log(title = "品牌", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcBrand dhcBrand)
    {
        dhcBrand.setCreateBy(String.valueOf(getUserId()));
        dhcBrand.setUpdateBy(String.valueOf(getUserId()));
        return toAjax(dhcBrandService.insertDhcBrand(dhcBrand));
    }

    /**
     * 修改品牌
     */
    @PreAuthorize("@ss.hasPermi('dhc:brand:edit')")
    @Log(title = "品牌", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcBrand dhcBrand)
    {
        dhcBrand.setUpdateBy(String.valueOf(getUserId()));
        return toAjax(dhcBrandService.updateDhcBrand(dhcBrand));
    }

    /**
     * 删除品牌
     */
    @PreAuthorize("@ss.hasPermi('dhc:brand:remove')")
    @Log(title = "品牌", businessType = BusinessType.DELETE)
	@DeleteMapping("/{brandIds}")
    public AjaxResult remove(@PathVariable Long[] brandIds)
    {
        return toAjax(dhcBrandService.deleteDhcBrandByBrandIds(brandIds));
    }
}
