package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProductApproveRecord;
import com.ruoyi.dhc.service.IDhcProductApproveRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品审核记录Controller
 * 
 * @author ruoyi
 * @date 2024-10-08
 */
@RestController
@RequestMapping("/dhc/record")
public class DhcProductApproveRecordController extends BaseController
{
    @Autowired
    private IDhcProductApproveRecordService dhcProductApproveRecordService;

    /**
     * 查询产品审核记录列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductApproveRecord dhcProductApproveRecord)
    {
        startPage();
        List<DhcProductApproveRecord> list = dhcProductApproveRecordService.selectDhcProductApproveRecordList(dhcProductApproveRecord);
        return getDataTable(list);
    }

    /**
     * 导出产品审核记录列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:record:export')")
    @Log(title = "产品审核记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductApproveRecord dhcProductApproveRecord)
    {
        List<DhcProductApproveRecord> list = dhcProductApproveRecordService.selectDhcProductApproveRecordList(dhcProductApproveRecord);
        ExcelUtil<DhcProductApproveRecord> util = new ExcelUtil<DhcProductApproveRecord>(DhcProductApproveRecord.class);
        util.exportExcel(response, list, "产品审核记录数据");
    }

    /**
     * 获取产品审核记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:record:query')")
    @GetMapping(value = "/{approveRecordId}")
    public AjaxResult getInfo(@PathVariable("approveRecordId") Long approveRecordId)
    {
        return success(dhcProductApproveRecordService.selectDhcProductApproveRecordByApproveRecordId(approveRecordId));
    }

    /**
     * 新增产品审核记录
     */
    @PreAuthorize("@ss.hasPermi('dhc:record:add')")
    @Log(title = "产品审核记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductApproveRecord dhcProductApproveRecord)
    {
        return toAjax(dhcProductApproveRecordService.insertDhcProductApproveRecord(dhcProductApproveRecord));
    }

    /**
     * 修改产品审核记录
     */
    @PreAuthorize("@ss.hasPermi('dhc:record:edit')")
    @Log(title = "产品审核记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductApproveRecord dhcProductApproveRecord)
    {
        return toAjax(dhcProductApproveRecordService.updateDhcProductApproveRecord(dhcProductApproveRecord));
    }

    /**
     * 删除产品审核记录
     */
    @PreAuthorize("@ss.hasPermi('dhc:record:remove')")
    @Log(title = "产品审核记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{approveRecordIds}")
    public AjaxResult remove(@PathVariable Long[] approveRecordIds)
    {
        return toAjax(dhcProductApproveRecordService.deleteDhcProductApproveRecordByApproveRecordIds(approveRecordIds));
    }
}
