package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProduct;
import com.ruoyi.dhc.service.IDhcProductService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品信息Controller
 * 
 * @author ruoyi
 * @date 2024-10-08
 */
@RestController
@RequestMapping("/dhc/product")
public class DhcProductController extends BaseController
{
    @Autowired
    private IDhcProductService dhcProductService;

    /**
     * 查询产品信息列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:product:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProduct dhcProduct)
    {
        startPage();
        List<DhcProduct> list = dhcProductService.selectDhcProductList(dhcProduct);
        return getDataTable(list);
    }

    /**
     * 导出产品信息列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:product:export')")
    @Log(title = "产品信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProduct dhcProduct)
    {
        List<DhcProduct> list = dhcProductService.selectDhcProductList(dhcProduct);
        ExcelUtil<DhcProduct> util = new ExcelUtil<DhcProduct>(DhcProduct.class);
        util.exportExcel(response, list, "产品信息数据");
    }

    /**
     * 获取产品信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:product:query')")
    @GetMapping(value = "/{productId}")
    public AjaxResult getInfo(@PathVariable("productId") Long productId)
    {
        return success(dhcProductService.selectDhcProductByProductId(productId));
    }

    /**
     * 新增产品信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:product:add')")
    @Log(title = "产品信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProduct dhcProduct)
    {
        return toAjax(dhcProductService.insertDhcProduct(dhcProduct));
    }

    /**
     * 修改产品信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:product:edit')")
    @Log(title = "产品信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProduct dhcProduct)
    {
        return toAjax(dhcProductService.updateDhcProduct(dhcProduct));
    }

    /**
     * 删除产品信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:product:remove')")
    @Log(title = "产品信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productIds}")
    public AjaxResult remove(@PathVariable Long[] productIds)
    {
        return toAjax(dhcProductService.deleteDhcProductByProductIds(productIds));
    }
}
