package com.ruoyi.web.controller.dhc;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dhc.domain.DhcProductLineArea;
import com.ruoyi.dhc.service.IDhcProductLineAreaService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.stream.Collectors;

/**
 * 产品线-区域类型-区域层级关系Controller
 * 
 * @author ruoyi
 * @date 2024-07-30
 */
@RestController
@RequestMapping("/dhc/productLineArea")
public class DhcProductLineAreaController extends BaseController
{
    @Autowired
    private IDhcProductLineAreaService dhcProductLineAreaService;

    /**
     * 查询产品线-区域类型-区域层级关系列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductLineArea dhcProductLineArea)
    {
        startPage();
        List<DhcProductLineArea> list = dhcProductLineAreaService.selectDhcProductLineAreaList(dhcProductLineArea);
        return getDataTable(list);
    }
    /**
     * 查询产品线-区域类型-区域层级关系列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:list')")
    @PostMapping("/queryList")
    public List<Map<String, String>> queryList(@RequestBody DhcProductLineArea dhcProductLineArea)
    {
        List<DhcProductLineArea> list = dhcProductLineAreaService.selectDhcProductLineAreaList(dhcProductLineArea);
        if ("areaType".equals(dhcProductLineArea.getType())) {
            list.forEach(item->{
                item.setAreaLevel(null);
            });
            list = list.stream().filter(distinctByKey(DhcProductLineArea::getAreaType)).distinct().collect(Collectors.toList());
        }
        List<Map<String, String>> mapList = new ArrayList<>();
        for (DhcProductLineArea productLineArea : list) {
            Map<String, String> map = new HashMap<>();
            if ("areaType".equals(dhcProductLineArea.getType())) {
                map.put("value", productLineArea.getAreaType());
                map.put("label", DictUtils.getDictLabel("area_type", productLineArea.getAreaType()));
            } else if ("areaLevel".equals(dhcProductLineArea.getType())) {
                map.put("value", productLineArea.getAreaLevel());
                map.put("label", DictUtils.getDictLabel("area_level", productLineArea.getAreaLevel()));
            }
            mapList.add(map);
        }
        return mapList;
    }
    /**
     * 导出产品线-区域类型-区域层级关系列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:export')")
    @Log(title = "产品线-区域类型-区域层级关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductLineArea dhcProductLineArea)
    {
        List<DhcProductLineArea> list = dhcProductLineAreaService.selectDhcProductLineAreaList(dhcProductLineArea);
        ExcelUtil<DhcProductLineArea> util = new ExcelUtil<DhcProductLineArea>(DhcProductLineArea.class);
        util.exportExcel(response, list, "产品线-区域类型-区域层级关系数据");
    }

    /**
     * 获取产品线-区域类型-区域层级关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:query')")
    @GetMapping(value = "/{productLineCode}")
    public AjaxResult getInfo(@PathVariable("productLineCode") String productLineCode)
    {
        return success(dhcProductLineAreaService.selectDhcProductLineAreaByProductLineCode(productLineCode));
    }

    /**
     * 新增产品线-区域类型-区域层级关系
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:add')")
    @Log(title = "产品线-区域类型-区域层级关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductLineArea dhcProductLineArea)
    {
        return toAjax(dhcProductLineAreaService.insertDhcProductLineArea(dhcProductLineArea));
    }

    /**
     * 修改产品线-区域类型-区域层级关系
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:edit')")
    @Log(title = "产品线-区域类型-区域层级关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductLineArea dhcProductLineArea)
    {
        return toAjax(dhcProductLineAreaService.updateDhcProductLineArea(dhcProductLineArea));
    }

    /**
     * 删除产品线-区域类型-区域层级关系
     */
    @PreAuthorize("@ss.hasPermi('dhc:area:remove')")
    @Log(title = "产品线-区域类型-区域层级关系", businessType = BusinessType.DELETE)
	@PostMapping("/remove")
    public AjaxResult remove(@RequestBody DhcProductLineArea dhcProductLineArea)
    {
        return toAjax(dhcProductLineAreaService.deleteDhcProductLineArea(dhcProductLineArea));
    }
    private static <T> Predicate<T> distinctByKey(Function<? super T, Object> keyExtractor) {
        Map<Object, Boolean> seen = new ConcurrentHashMap<>();
        return t -> seen.putIfAbsent(keyExtractor.apply(t), Boolean.TRUE) == null;
    }
}
