package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProductPropertyDef;
import com.ruoyi.dhc.service.IDhcProductPropertyDefService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品属性定义Controller
 * 
 * @author ruoyi
 * @date 2024-10-14
 */
@RestController
@RequestMapping("/dhc/def")
public class DhcProductPropertyDefController extends BaseController
{
    @Autowired
    private IDhcProductPropertyDefService dhcProductPropertyDefService;

    /**
     * 查询产品属性定义列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:def:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductPropertyDef dhcProductPropertyDef)
    {
        startPage();
        List<DhcProductPropertyDef> list = dhcProductPropertyDefService.selectDhcProductPropertyDefList(dhcProductPropertyDef);
        return getDataTable(list);
    }

    /**
     * 导出产品属性定义列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:def:export')")
    @Log(title = "产品属性定义", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductPropertyDef dhcProductPropertyDef)
    {
        List<DhcProductPropertyDef> list = dhcProductPropertyDefService.selectDhcProductPropertyDefList(dhcProductPropertyDef);
        ExcelUtil<DhcProductPropertyDef> util = new ExcelUtil<DhcProductPropertyDef>(DhcProductPropertyDef.class);
        util.exportExcel(response, list, "产品属性定义数据");
    }

    /**
     * 获取产品属性定义详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:def:query')")
    @GetMapping(value = "/{productPropertyDefId}")
    public AjaxResult getInfo(@PathVariable("productPropertyDefId") Long productPropertyDefId)
    {
        return success(dhcProductPropertyDefService.selectDhcProductPropertyDefByProductPropertyDefId(productPropertyDefId));
    }

    /**
     * 新增产品属性定义
     */
    @PreAuthorize("@ss.hasPermi('dhc:def:add')")
    @Log(title = "产品属性定义", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductPropertyDef dhcProductPropertyDef)
    {
        return toAjax(dhcProductPropertyDefService.insertDhcProductPropertyDef(dhcProductPropertyDef));
    }

    /**
     * 修改产品属性定义
     */
    @PreAuthorize("@ss.hasPermi('dhc:def:edit')")
    @Log(title = "产品属性定义", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductPropertyDef dhcProductPropertyDef)
    {
        return toAjax(dhcProductPropertyDefService.updateDhcProductPropertyDef(dhcProductPropertyDef));
    }

    /**
     * 删除产品属性定义
     */
    @PreAuthorize("@ss.hasPermi('dhc:def:remove')")
    @Log(title = "产品属性定义", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productPropertyDefIds}")
    public AjaxResult remove(@PathVariable Long[] productPropertyDefIds)
    {
        return toAjax(dhcProductPropertyDefService.deleteDhcProductPropertyDefByProductPropertyDefIds(productPropertyDefIds));
    }
}
