package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProductPropertyTable;
import com.ruoyi.dhc.service.IDhcProductPropertyTableService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品属性模板Controller
 * 
 * @author ruoyi
 * @date 2024-10-14
 */
@RestController
@RequestMapping("/dhc/table")
public class DhcProductPropertyTableController extends BaseController
{
    @Autowired
    private IDhcProductPropertyTableService dhcProductPropertyTableService;

    /**
     * 查询产品属性模板列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:table:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductPropertyTable dhcProductPropertyTable)
    {
        startPage();
        List<DhcProductPropertyTable> list = dhcProductPropertyTableService.selectDhcProductPropertyTableList(dhcProductPropertyTable);
        return getDataTable(list);
    }

    /**
     * 导出产品属性模板列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:table:export')")
    @Log(title = "产品属性模板", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductPropertyTable dhcProductPropertyTable)
    {
        List<DhcProductPropertyTable> list = dhcProductPropertyTableService.selectDhcProductPropertyTableList(dhcProductPropertyTable);
        ExcelUtil<DhcProductPropertyTable> util = new ExcelUtil<DhcProductPropertyTable>(DhcProductPropertyTable.class);
        util.exportExcel(response, list, "产品属性模板数据");
    }

    /**
     * 获取产品属性模板详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:table:query')")
    @GetMapping(value = "/{productPropertyTableId}")
    public AjaxResult getInfo(@PathVariable("productPropertyTableId") Long productPropertyTableId)
    {
        return success(dhcProductPropertyTableService.selectDhcProductPropertyTableByProductPropertyTableId(productPropertyTableId));
    }

    /**
     * 新增产品属性模板
     */
    @PreAuthorize("@ss.hasPermi('dhc:table:add')")
    @Log(title = "产品属性模板", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductPropertyTable dhcProductPropertyTable)
    {
        return toAjax(dhcProductPropertyTableService.insertDhcProductPropertyTable(dhcProductPropertyTable));
    }

    /**
     * 修改产品属性模板
     */
    @PreAuthorize("@ss.hasPermi('dhc:table:edit')")
    @Log(title = "产品属性模板", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductPropertyTable dhcProductPropertyTable)
    {
        return toAjax(dhcProductPropertyTableService.updateDhcProductPropertyTable(dhcProductPropertyTable));
    }

    /**
     * 删除产品属性模板
     */
    @PreAuthorize("@ss.hasPermi('dhc:table:remove')")
    @Log(title = "产品属性模板", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productPropertyTableIds}")
    public AjaxResult remove(@PathVariable Long[] productPropertyTableIds)
    {
        return toAjax(dhcProductPropertyTableService.deleteDhcProductPropertyTableByProductPropertyTableIds(productPropertyTableIds));
    }
}
