package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProductPropertyTableDetail;
import com.ruoyi.dhc.service.IDhcProductPropertyTableDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品属性模板属性Controller
 * 
 * @author ruoyi
 * @date 2024-10-14
 */
@RestController
@RequestMapping("/dhc/detail")
public class DhcProductPropertyTableDetailController extends BaseController
{
    @Autowired
    private IDhcProductPropertyTableDetailService dhcProductPropertyTableDetailService;

    /**
     * 查询产品属性模板属性列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:detail:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductPropertyTableDetail dhcProductPropertyTableDetail)
    {
        startPage();
        List<DhcProductPropertyTableDetail> list = dhcProductPropertyTableDetailService.selectDhcProductPropertyTableDetailList(dhcProductPropertyTableDetail);
        return getDataTable(list);
    }

    /**
     * 导出产品属性模板属性列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:detail:export')")
    @Log(title = "产品属性模板属性", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductPropertyTableDetail dhcProductPropertyTableDetail)
    {
        List<DhcProductPropertyTableDetail> list = dhcProductPropertyTableDetailService.selectDhcProductPropertyTableDetailList(dhcProductPropertyTableDetail);
        ExcelUtil<DhcProductPropertyTableDetail> util = new ExcelUtil<DhcProductPropertyTableDetail>(DhcProductPropertyTableDetail.class);
        util.exportExcel(response, list, "产品属性模板属性数据");
    }

    /**
     * 获取产品属性模板属性详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:detail:query')")
    @GetMapping(value = "/{productPropertyTableDetailId}")
    public AjaxResult getInfo(@PathVariable("productPropertyTableDetailId") Long productPropertyTableDetailId)
    {
        return success(dhcProductPropertyTableDetailService.selectDhcProductPropertyTableDetailByProductPropertyTableDetailId(productPropertyTableDetailId));
    }

    /**
     * 新增产品属性模板属性
     */
    @PreAuthorize("@ss.hasPermi('dhc:detail:add')")
    @Log(title = "产品属性模板属性", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductPropertyTableDetail dhcProductPropertyTableDetail)
    {
        return toAjax(dhcProductPropertyTableDetailService.insertDhcProductPropertyTableDetail(dhcProductPropertyTableDetail));
    }

    /**
     * 修改产品属性模板属性
     */
    @PreAuthorize("@ss.hasPermi('dhc:detail:edit')")
    @Log(title = "产品属性模板属性", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductPropertyTableDetail dhcProductPropertyTableDetail)
    {
        return toAjax(dhcProductPropertyTableDetailService.updateDhcProductPropertyTableDetail(dhcProductPropertyTableDetail));
    }

    /**
     * 删除产品属性模板属性
     */
    @PreAuthorize("@ss.hasPermi('dhc:detail:remove')")
    @Log(title = "产品属性模板属性", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productPropertyTableDetailIds}")
    public AjaxResult remove(@PathVariable Long[] productPropertyTableDetailIds)
    {
        return toAjax(dhcProductPropertyTableDetailService.deleteDhcProductPropertyTableDetailByProductPropertyTableDetailIds(productPropertyTableDetailIds));
    }
}
