package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProductPropertyTableRel;
import com.ruoyi.dhc.service.IDhcProductPropertyTableRelService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品属性模板关联Controller
 * 
 * @author ruoyi
 * @date 2024-10-14
 */
@RestController
@RequestMapping("/dhc/rel")
public class DhcProductPropertyTableRelController extends BaseController
{
    @Autowired
    private IDhcProductPropertyTableRelService dhcProductPropertyTableRelService;

    /**
     * 查询产品属性模板关联列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:rel:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductPropertyTableRel dhcProductPropertyTableRel)
    {
        startPage();
        List<DhcProductPropertyTableRel> list = dhcProductPropertyTableRelService.selectDhcProductPropertyTableRelList(dhcProductPropertyTableRel);
        return getDataTable(list);
    }

    /**
     * 导出产品属性模板关联列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:rel:export')")
    @Log(title = "产品属性模板关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductPropertyTableRel dhcProductPropertyTableRel)
    {
        List<DhcProductPropertyTableRel> list = dhcProductPropertyTableRelService.selectDhcProductPropertyTableRelList(dhcProductPropertyTableRel);
        ExcelUtil<DhcProductPropertyTableRel> util = new ExcelUtil<DhcProductPropertyTableRel>(DhcProductPropertyTableRel.class);
        util.exportExcel(response, list, "产品属性模板关联数据");
    }

    /**
     * 获取产品属性模板关联详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:rel:query')")
    @GetMapping(value = "/{productPropertyTableRelId}")
    public AjaxResult getInfo(@PathVariable("productPropertyTableRelId") Long productPropertyTableRelId)
    {
        return success(dhcProductPropertyTableRelService.selectDhcProductPropertyTableRelByProductPropertyTableRelId(productPropertyTableRelId));
    }

    /**
     * 新增产品属性模板关联
     */
    @PreAuthorize("@ss.hasPermi('dhc:rel:add')")
    @Log(title = "产品属性模板关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductPropertyTableRel dhcProductPropertyTableRel)
    {
        return toAjax(dhcProductPropertyTableRelService.insertDhcProductPropertyTableRel(dhcProductPropertyTableRel));
    }

    /**
     * 修改产品属性模板关联
     */
    @PreAuthorize("@ss.hasPermi('dhc:rel:edit')")
    @Log(title = "产品属性模板关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductPropertyTableRel dhcProductPropertyTableRel)
    {
        return toAjax(dhcProductPropertyTableRelService.updateDhcProductPropertyTableRel(dhcProductPropertyTableRel));
    }

    /**
     * 删除产品属性模板关联
     */
    @PreAuthorize("@ss.hasPermi('dhc:rel:remove')")
    @Log(title = "产品属性模板关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productPropertyTableRelIds}")
    public AjaxResult remove(@PathVariable Long[] productPropertyTableRelIds)
    {
        return toAjax(dhcProductPropertyTableRelService.deleteDhcProductPropertyTableRelByProductPropertyTableRelIds(productPropertyTableRelIds));
    }
}
