package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProductPropertyValue;
import com.ruoyi.dhc.service.IDhcProductPropertyValueService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 产品属性取值Controller
 * 
 * @author ruoyi
 * @date 2024-10-14
 */
@RestController
@RequestMapping("/dhc/value")
public class DhcProductPropertyValueController extends BaseController
{
    @Autowired
    private IDhcProductPropertyValueService dhcProductPropertyValueService;

    /**
     * 查询产品属性取值列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:value:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductPropertyValue dhcProductPropertyValue)
    {
        startPage();
        List<DhcProductPropertyValue> list = dhcProductPropertyValueService.selectDhcProductPropertyValueList(dhcProductPropertyValue);
        return getDataTable(list);
    }

    /**
     * 导出产品属性取值列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:value:export')")
    @Log(title = "产品属性取值", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductPropertyValue dhcProductPropertyValue)
    {
        List<DhcProductPropertyValue> list = dhcProductPropertyValueService.selectDhcProductPropertyValueList(dhcProductPropertyValue);
        ExcelUtil<DhcProductPropertyValue> util = new ExcelUtil<DhcProductPropertyValue>(DhcProductPropertyValue.class);
        util.exportExcel(response, list, "产品属性取值数据");
    }

    /**
     * 获取产品属性取值详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:value:query')")
    @GetMapping(value = "/{productPropertyId}")
    public AjaxResult getInfo(@PathVariable("productPropertyId") Long productPropertyId)
    {
        return success(dhcProductPropertyValueService.selectDhcProductPropertyValueByProductPropertyId(productPropertyId));
    }

    /**
     * 新增产品属性取值
     */
    @PreAuthorize("@ss.hasPermi('dhc:value:add')")
    @Log(title = "产品属性取值", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductPropertyValue dhcProductPropertyValue)
    {
        return toAjax(dhcProductPropertyValueService.insertDhcProductPropertyValue(dhcProductPropertyValue));
    }

    /**
     * 修改产品属性取值
     */
    @PreAuthorize("@ss.hasPermi('dhc:value:edit')")
    @Log(title = "产品属性取值", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductPropertyValue dhcProductPropertyValue)
    {
        return toAjax(dhcProductPropertyValueService.updateDhcProductPropertyValue(dhcProductPropertyValue));
    }

    /**
     * 删除产品属性取值
     */
    @PreAuthorize("@ss.hasPermi('dhc:value:remove')")
    @Log(title = "产品属性取值", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productPropertyIds}")
    public AjaxResult remove(@PathVariable Long[] productPropertyIds)
    {
        return toAjax(dhcProductPropertyValueService.deleteDhcProductPropertyValueByProductPropertyIds(productPropertyIds));
    }
}
