package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcProductionBaseLine;
import com.ruoyi.dhc.service.IDhcProductionBaseLineService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 生产基地与产品线关系Controller
 * 
 * @author ruoyi
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/dhc/line")
public class DhcProductionBaseLineController extends BaseController
{
    @Autowired
    private IDhcProductionBaseLineService dhcProductionBaseLineService;

    /**
     * 查询生产基地与产品线关系列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:line:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcProductionBaseLine dhcProductionBaseLine)
    {
        startPage();
        List<DhcProductionBaseLine> list = dhcProductionBaseLineService.selectDhcProductionBaseLineList(dhcProductionBaseLine);
        return getDataTable(list);
    }

    /**
     * 导出生产基地与产品线关系列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:line:export')")
    @Log(title = "生产基地与产品线关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcProductionBaseLine dhcProductionBaseLine)
    {
        List<DhcProductionBaseLine> list = dhcProductionBaseLineService.selectDhcProductionBaseLineList(dhcProductionBaseLine);
        ExcelUtil<DhcProductionBaseLine> util = new ExcelUtil<DhcProductionBaseLine>(DhcProductionBaseLine.class);
        util.exportExcel(response, list, "生产基地与产品线关系数据");
    }

    /**
     * 获取生产基地与产品线关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:line:query')")
    @GetMapping(value = "/{productLineCode}")
    public AjaxResult getInfo(@PathVariable("productLineCode") String productLineCode)
    {
        return success(dhcProductionBaseLineService.selectDhcProductionBaseLineByProductLineCode(productLineCode));
    }

    /**
     * 新增生产基地与产品线关系
     */
    @PreAuthorize("@ss.hasPermi('dhc:line:add')")
    @Log(title = "生产基地与产品线关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcProductionBaseLine dhcProductionBaseLine)
    {
        return toAjax(dhcProductionBaseLineService.insertDhcProductionBaseLine(dhcProductionBaseLine));
    }

    /**
     * 修改生产基地与产品线关系
     */
    @PreAuthorize("@ss.hasPermi('dhc:line:edit')")
    @Log(title = "生产基地与产品线关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcProductionBaseLine dhcProductionBaseLine)
    {
        return toAjax(dhcProductionBaseLineService.updateDhcProductionBaseLine(dhcProductionBaseLine));
    }

    /**
     * 删除生产基地与产品线关系
     */
    @PreAuthorize("@ss.hasPermi('dhc:line:remove')")
    @Log(title = "生产基地与产品线关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{productLineCodes}")
    public AjaxResult remove(@PathVariable String[] productLineCodes)
    {
        return toAjax(dhcProductionBaseLineService.deleteDhcProductionBaseLineByProductLineCodes(productLineCodes));
    }
}
