package com.ruoyi.web.controller.dhc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.dhc.domain.DhcSupplier;
import com.ruoyi.dhc.service.IDhcSupplierService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 供应商信息Controller
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
@RestController
@RequestMapping("/dhc/supplier")
public class DhcSupplierController extends BaseController
{
    @Autowired
    private IDhcSupplierService dhcSupplierService;

    /**
     * 查询供应商信息列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:supplier:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcSupplier dhcSupplier)
    {
        startPage();
        List<DhcSupplier> list = dhcSupplierService.selectDhcSupplierList(dhcSupplier);
        return getDataTable(list);
    }

    /**
     * 导出供应商信息列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:supplier:export')")
    @Log(title = "供应商信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcSupplier dhcSupplier)
    {
        List<DhcSupplier> list = dhcSupplierService.selectDhcSupplierList(dhcSupplier);
        ExcelUtil<DhcSupplier> util = new ExcelUtil<DhcSupplier>(DhcSupplier.class);
        util.exportExcel(response, list, "供应商信息数据");
    }

    /**
     * 获取供应商信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:supplier:query')")
    @GetMapping(value = "/{supplierId}")
    public AjaxResult getInfo(@PathVariable("supplierId") Long supplierId)
    {
        return success(dhcSupplierService.selectDhcSupplierBySupplierId(supplierId));
    }

    /**
     * 新增供应商信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:supplier:add')")
    @Log(title = "供应商信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcSupplier dhcSupplier)
    {
        dhcSupplier.setCreateBy(String.valueOf(getUserId()));
        dhcSupplier.setUpdateBy(String.valueOf(getUserId()));
        return toAjax(dhcSupplierService.insertDhcSupplier(dhcSupplier));
    }

    /**
     * 修改供应商信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:supplier:edit')")
    @Log(title = "供应商信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcSupplier dhcSupplier)
    {
        dhcSupplier.setUpdateBy(String.valueOf(getUserId()));
        return toAjax(dhcSupplierService.updateDhcSupplier(dhcSupplier));
    }

    /**
     * 删除供应商信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:supplier:remove')")
    @Log(title = "供应商信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{supplierIds}")
    public AjaxResult remove(@PathVariable Long[] supplierIds)
    {
        return toAjax(dhcSupplierService.deleteDhcSupplierBySupplierIds(supplierIds));
    }
}
