package com.ruoyi.web.controller.system;

import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.dhc.domain.DhcDataAuth;
import com.ruoyi.dhc.domain.DhcDataAuthDetail;
import com.ruoyi.dhc.service.IDhcDataAuthService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 数据权限Controller
 * 
 * @author ruoyi
 * @date 2024-08-01
 */
@RestController
@RequestMapping("/dhc/authData")
public class DhcDataAuthController extends BaseController
{
    @Autowired
    private IDhcDataAuthService dhcDataAuthService;

    /**
     * 查询数据权限列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:authData:list')")
    @GetMapping("/list")
    public TableDataInfo list(DhcDataAuth dhcDataAuth)
    {
        startPage();
        List<DhcDataAuth> list = dhcDataAuthService.selectDhcDataAuthByPage(dhcDataAuth);
        return getDataTable(list);
    }

    /**
     * 导出数据权限列表
     */
    @PreAuthorize("@ss.hasPermi('dhc:authData:export')")
    @Log(title = "数据权限", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DhcDataAuth dhcDataAuth)
    {
        List<DhcDataAuth> list = dhcDataAuthService.selectDhcDataAuthList(dhcDataAuth);
        ExcelUtil<DhcDataAuth> util = new ExcelUtil<DhcDataAuth>(DhcDataAuth.class);
        util.exportExcel(response, list, "数据权限数据");
    }

    /**
     * 获取数据权限详细信息
     */
    @PreAuthorize("@ss.hasPermi('dhc:authData:query')")
    @GetMapping(value = "/{dataAuthId}")
    public AjaxResult getInfo(@PathVariable("dataAuthId") Long dataAuthId)
    {
        return success(dhcDataAuthService.selectDhcDataAuthByDataAuthId(dataAuthId));
    }

    /**
     * 新增数据权限
     */
    @PreAuthorize("@ss.hasPermi('dhc:authData:add')")
    @Log(title = "数据权限", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DhcDataAuth dhcDataAuth)
    {
        return toAjax(dhcDataAuthService.insertDhcDataAuth(dhcDataAuth));
    }

    /**
     * 修改数据权限
     */
    @PreAuthorize("@ss.hasPermi('dhc:authData:edit')")
    @Log(title = "数据权限", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DhcDataAuth dhcDataAuth)
    {
        return toAjax(dhcDataAuthService.updateDhcDataAuth(dhcDataAuth));
    }

    @PreAuthorize("@ss.hasPermi('dhc:authData:add')")
    @Log(title = "数据权限", businessType = BusinessType.INSERT)
    @PostMapping("batchAdd")
    public AjaxResult batchAdd(@RequestBody List<DhcDataAuth> dhcDataAuth)
    {
        return toAjax(dhcDataAuthService.insertDhcDataAuthBatch(dhcDataAuth));
    }

    /**
     * 删除数据权限
     */
    @PreAuthorize("@ss.hasPermi('dhc:authData:remove')")
    @Log(title = "数据权限", businessType = BusinessType.DELETE)
	@DeleteMapping("/{dataAuthIds}")
    public AjaxResult remove(@PathVariable Long[] dataAuthIds)
    {
        return toAjax(dhcDataAuthService.deleteDhcDataAuthByDataAuthIds(dataAuthIds));
    }
    /**
     * 批量删除数据权限
     */
    @PreAuthorize("@ss.hasPermi('dhc:authData:remove')")
    @Log(title = "数据权限", businessType = BusinessType.DELETE)
    @PostMapping(value = "/removeBatch")
    public AjaxResult removeBatch(@RequestBody List<DhcDataAuthDetail> detailList)
    {
        return toAjax(dhcDataAuthService.deleteDhcDataAuth(detailList));
    }
}
