package com.ruoyi.dhc.service;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.core.domain.entity.DhcArea;

import java.util.List;

/**
 * 区域Service接口
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
public interface IDhcAreaService 
{
    /**
     * 查询区域
     * 
     * @param areaId 区域主键
     * @return 区域
     */
    public DhcArea selectDhcAreaByAreaId(Long areaId);

    /**
     * 查询区域列表
     * 
     * @param dhcArea 区域
     * @return 区域集合
     */
    public List<DhcArea> selectDhcAreaList(DhcArea dhcArea);

    /**
     * 新增区域
     * 
     * @param dhcArea 区域
     * @return 结果
     */
    public int insertDhcArea(DhcArea dhcArea);

    /**
     * 修改区域
     * 
     * @param dhcArea 区域
     * @return 结果
     */
    public int updateDhcArea(DhcArea dhcArea);

    /**
     * 批量删除区域
     * 
     * @param areaIds 需要删除的区域主键集合
     * @return 结果
     */
    public int deleteDhcAreaByAreaIds(Long[] areaIds);

    /**
     * 删除区域信息
     * 
     * @param areaId 区域主键
     * @return 结果
     */
    public int deleteDhcAreaByAreaId(Long areaId);

    /**
     * 查询区域树结构信息
     *
     * @param dhcArea 区域
     * @return 区域树信息集合
     */
    public List<TreeSelect> selectAreaTreeList(DhcArea dhcArea);

    /**
     * 构建前端所需要树结构
     *
     * @param areas 区域列表
     * @return 树结构列表
     */
    public List<DhcArea> buildAreaTree(List<DhcArea> areas);

    /**
     * 构建前端所需要下拉树结构
     *
     * @param areas 区域列表
     * @return 下拉树结构列表
     */
    public List<TreeSelect> buildAreaTreeSelect(List<DhcArea> areas);
}
