package com.ruoyi.dhc.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dhc.mapper.DhcBrandMapper;
import com.ruoyi.dhc.domain.DhcBrand;
import com.ruoyi.dhc.service.IDhcBrandService;

/**
 * 品牌Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
@Service
public class DhcBrandServiceImpl implements IDhcBrandService 
{
    @Autowired
    private DhcBrandMapper dhcBrandMapper;

    /**
     * 查询品牌
     * 
     * @param brandId 品牌主键
     * @return 品牌
     */
    @Override
    public DhcBrand selectDhcBrandByBrandId(Long brandId)
    {
        return dhcBrandMapper.selectDhcBrandByBrandId(brandId);
    }

    /**
     * 查询品牌列表
     * 
     * @param dhcBrand 品牌
     * @return 品牌
     */
    @Override
    public List<DhcBrand> selectDhcBrandList(DhcBrand dhcBrand)
    {
        dhcBrand.setDelFlag("0");
        return dhcBrandMapper.selectDhcBrandList(dhcBrand);
    }

    /**
     * 新增品牌
     * 
     * @param dhcBrand 品牌
     * @return 结果
     */
    @Override
    public int insertDhcBrand(DhcBrand dhcBrand)
    {
        dhcBrand.setCreateTime(DateUtils.getNowDate());
        dhcBrand.setUpdateTime(DateUtils.getNowDate());
        return dhcBrandMapper.insertDhcBrand(dhcBrand);
    }

    /**
     * 修改品牌
     * 
     * @param dhcBrand 品牌
     * @return 结果
     */
    @Override
    public int updateDhcBrand(DhcBrand dhcBrand)
    {
        dhcBrand.setUpdateTime(DateUtils.getNowDate());
        return dhcBrandMapper.updateDhcBrand(dhcBrand);
    }

    /**
     * 批量删除品牌
     * 
     * @param brandIds 需要删除的品牌主键
     * @return 结果
     */
    @Override
    public int deleteDhcBrandByBrandIds(Long[] brandIds)
    {
        return dhcBrandMapper.deleteDhcBrandByBrandIds(brandIds);
    }

    /**
     * 删除品牌信息
     * 
     * @param brandId 品牌主键
     * @return 结果
     */
    @Override
    public int deleteDhcBrandByBrandId(Long brandId)
    {
        return dhcBrandMapper.deleteDhcBrandByBrandId(brandId);
    }
}
