package com.ruoyi.dhc.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dhc.mapper.DhcCountryMapper;
import com.ruoyi.dhc.domain.DhcCountry;
import com.ruoyi.dhc.service.IDhcCountryService;

/**
 * 国家Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
@Service
public class DhcCountryServiceImpl implements IDhcCountryService 
{
    @Autowired
    private DhcCountryMapper dhcCountryMapper;

    /**
     * 查询国家
     * 
     * @param countryId 国家主键
     * @return 国家
     */
    @Override
    public DhcCountry selectDhcCountryByCountryId(Long countryId)
    {
        return dhcCountryMapper.selectDhcCountryByCountryId(countryId);
    }

    /**
     * 查询国家列表
     * 
     * @param dhcCountry 国家
     * @return 国家
     */
    @Override
    public List<DhcCountry> selectDhcCountryList(DhcCountry dhcCountry)
    {
        dhcCountry.setDelFlag("0");
        return dhcCountryMapper.selectDhcCountryList(dhcCountry);
    }

    /**
     * 新增国家
     * 
     * @param dhcCountry 国家
     * @return 结果
     */
    @Override
    public int insertDhcCountry(DhcCountry dhcCountry)
    {
        dhcCountry.setCreateTime(DateUtils.getNowDate());
        dhcCountry.setUpdateTime(DateUtils.getNowDate());
        return dhcCountryMapper.insertDhcCountry(dhcCountry);
    }

    /**
     * 修改国家
     * 
     * @param dhcCountry 国家
     * @return 结果
     */
    @Override
    public int updateDhcCountry(DhcCountry dhcCountry)
    {
        dhcCountry.setUpdateTime(DateUtils.getNowDate());
        return dhcCountryMapper.updateDhcCountry(dhcCountry);
    }

    /**
     * 批量删除国家
     * 
     * @param countryIds 需要删除的国家主键
     * @return 结果
     */
    @Override
    public int deleteDhcCountryByCountryIds(Long[] countryIds)
    {
        return dhcCountryMapper.deleteDhcCountryByCountryIds(countryIds);
    }

    /**
     * 删除国家信息
     * 
     * @param countryId 国家主键
     * @return 结果
     */
    @Override
    public int deleteDhcCountryByCountryId(Long countryId)
    {
        return dhcCountryMapper.deleteDhcCountryByCountryId(countryId);
    }
}
