package com.ruoyi.dhc.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dhc.mapper.DhcSupplierMapper;
import com.ruoyi.dhc.domain.DhcSupplier;
import com.ruoyi.dhc.service.IDhcSupplierService;

/**
 * 供应商信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
@Service
public class DhcSupplierServiceImpl implements IDhcSupplierService 
{
    @Autowired
    private DhcSupplierMapper dhcSupplierMapper;

    /**
     * 查询供应商信息
     * 
     * @param supplierId 供应商信息主键
     * @return 供应商信息
     */
    @Override
    public DhcSupplier selectDhcSupplierBySupplierId(Long supplierId)
    {
        return dhcSupplierMapper.selectDhcSupplierBySupplierId(supplierId);
    }

    /**
     * 查询供应商信息列表
     * 
     * @param dhcSupplier 供应商信息
     * @return 供应商信息
     */
    @Override
    public List<DhcSupplier> selectDhcSupplierList(DhcSupplier dhcSupplier)
    {
        dhcSupplier.setDelFlag("0");
        return dhcSupplierMapper.selectDhcSupplierList(dhcSupplier);
    }

    /**
     * 新增供应商信息
     * 
     * @param dhcSupplier 供应商信息
     * @return 结果
     */
    @Override
    public int insertDhcSupplier(DhcSupplier dhcSupplier)
    {
        dhcSupplier.setCreateTime(DateUtils.getNowDate());
        dhcSupplier.setUpdateTime(DateUtils.getNowDate());
        return dhcSupplierMapper.insertDhcSupplier(dhcSupplier);
    }

    /**
     * 修改供应商信息
     * 
     * @param dhcSupplier 供应商信息
     * @return 结果
     */
    @Override
    public int updateDhcSupplier(DhcSupplier dhcSupplier)
    {
        dhcSupplier.setUpdateTime(DateUtils.getNowDate());
        return dhcSupplierMapper.updateDhcSupplier(dhcSupplier);
    }

    /**
     * 批量删除供应商信息
     * 
     * @param supplierIds 需要删除的供应商信息主键
     * @return 结果
     */
    @Override
    public int deleteDhcSupplierBySupplierIds(Long[] supplierIds)
    {
        return dhcSupplierMapper.deleteDhcSupplierBySupplierIds(supplierIds);
    }

    /**
     * 删除供应商信息信息
     * 
     * @param supplierId 供应商信息主键
     * @return 结果
     */
    @Override
    public int deleteDhcSupplierBySupplierId(Long supplierId)
    {
        return dhcSupplierMapper.deleteDhcSupplierBySupplierId(supplierId);
    }
}
