package com.ruoyi.dhc.service.impl;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.dhc.domain.DhcDataAuth;
import com.ruoyi.dhc.domain.DhcDataAuthDetail;
import com.ruoyi.dhc.mapper.DhcDataAuthMapper;
import com.ruoyi.dhc.service.IDhcDataAuthService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 数据权限Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-01
 */
@Service
public class DhcDataAuthServiceImpl implements IDhcDataAuthService 
{
    @Autowired
    private DhcDataAuthMapper dhcDataAuthMapper;

    /**
     * 查询数据权限
     * 
     * @param dataAuthId 数据权限主键
     * @return 数据权限
     */
    @Override
    public DhcDataAuth selectDhcDataAuthByDataAuthId(Long dataAuthId)
    {
        return dhcDataAuthMapper.selectDhcDataAuthByDataAuthId(dataAuthId);
    }

    /**
     * 查询数据权限列表
     * 
     * @param dhcDataAuth 数据权限
     * @return 数据权限
     */
    @Override
    public List<DhcDataAuth> selectDhcDataAuthList(DhcDataAuth dhcDataAuth)
    {   List<DhcDataAuth> list = dhcDataAuthMapper.selectDhcDataAuthList(dhcDataAuth);
        list.forEach(item->{
            item.setDetailType("0");
            List<DhcDataAuthDetail> detailList = dhcDataAuthMapper.selectDhcDataAuthDetailList(item);
            String[] array = item.getDeptAllId().split("/");
            List<Long> deptIds = new ArrayList<>();
            for (String deptId : array) {
                deptIds.add(Long.valueOf(deptId));
            }
            item.setDeptIds(deptIds);
            item.setDetailList(detailList);
            item.setEditFlag(false);
            item.setDetailCodes(detailList.stream().map(model->{return model.getDetailCode();}).collect(Collectors.toList()));
            item.setDetailNames(StringUtils.join(detailList.stream().map(model->{return model.getDetailName();}).collect(Collectors.toList()),"/"));
        });
        return list;
    }

    /**
     * 新增数据权限
     * 
     * @param dhcDataAuth 数据权限
     * @return 结果
     */
    @Override
    public int insertDhcDataAuth(DhcDataAuth dhcDataAuth)
    {
        /*
        if (dhcDataAuth.getDataAuthId() != null) {
            dhcDataAuthMapper.deleteDhcDataAuthByDataAuthId(dhcDataAuth.getDataAuthId());
            dhcDataAuthMapper.deleteDataAuthDetailByDataAuthIds(dhcDataAuth);
        }
        int count = dhcDataAuthMapper.insertDhcDataAuth(dhcDataAuth);
        dhcDataAuth.getDetailList().forEach(item->{
            item.setDataAuthId(dhcDataAuth.getDataAuthId());
        });
        dhcDataAuthMapper.batchAddDataAuthDetail(dhcDataAuth.getDetailList());
        */

        Long dataAuthId;
        int count = 0;

        // 首先按条件找现有已存在的头表，如果已经有了，就不用再建了。
        List<DhcDataAuth> dhcDataAuthList = dhcDataAuthMapper.selectDhcDataAuthList(dhcDataAuth);
        if (CollectionUtils.isNotEmpty(dhcDataAuthList)) {
            DhcDataAuth first = dhcDataAuthList.get(0);
            dataAuthId = first.getDataAuthId();
        } else {
            dhcDataAuthMapper.insertDhcDataAuth(dhcDataAuth);
            dataAuthId = dhcDataAuth.getDataAuthId();
        }

        // 找到现有的所有明细
        DhcDataAuth params = new DhcDataAuth();
        params.setDataAuthId(dataAuthId);
        params.setDetailType("0");
        List<DhcDataAuthDetail> detailList = dhcDataAuthMapper.selectDhcDataAuthDetailList(params);

        // 遍历明细，检查是否存在，只对不存在的进行插入
        List<DhcDataAuthDetail> newDetailList = dhcDataAuth.getDetailList().stream()
                .filter(itemToAdd -> detailList.stream().noneMatch(item -> item.getDetailCode().equals(itemToAdd.getDetailCode())))
                .peek(item-> item.setDataAuthId(dataAuthId)).collect(Collectors.toList());

        if (CollectionUtils.isNotEmpty(newDetailList)) {
            dhcDataAuthMapper.batchAddDataAuthDetail(newDetailList);
        }

        return count;
    }

    /**
     * 修改数据权限
     * 
     * @param dhcDataAuth 数据权限
     * @return 结果
     */
    @Override
    public int updateDhcDataAuth(DhcDataAuth dhcDataAuth)
    {
        dhcDataAuthMapper.deleteDataAuthDetailByDataAuthIds(dhcDataAuth);
        dhcDataAuthMapper.batchAddDataAuthDetail(dhcDataAuth.getDetailList());
        return dhcDataAuthMapper.updateDhcDataAuth(dhcDataAuth);
    }

    /**
     * 批量删除数据权限
     * 
     * @param dataAuthIds 需要删除的数据权限主键
     * @return 结果
     */
    @Override
    public int deleteDhcDataAuthByDataAuthIds(Long[] dataAuthIds)
    {   DhcDataAuth dhcDataAuth = new DhcDataAuth();
        dhcDataAuth.setDataAuthIds(new ArrayList<>(Arrays.asList(dataAuthIds)));
        dhcDataAuthMapper.deleteDataAuthDetailByDataAuthIds(dhcDataAuth);
        return dhcDataAuthMapper.deleteDhcDataAuthByDataAuthIds(dataAuthIds);
    }

    /**
     * 删除数据权限信息
     * 
     * @param detailList
     * @return 结果
     */
    @Override
    public int deleteDhcDataAuth(List<DhcDataAuthDetail> detailList)
    {
        for (DhcDataAuthDetail detail : detailList) {
            detail.setDetailType("0");
            dhcDataAuthMapper.deleteDataAuthDetail(detail);
            Integer count = dhcDataAuthMapper.selectDataAuthDetailCount(detail);
            if (count == 0) {
                dhcDataAuthMapper.deleteDhcDataAuthByDataAuthId(detail.getDataAuthId());
            }
        }
        return 1;
    }

    /**
     * 查询数据权限列表
     *
     * @param dhcDataAuth 数据权限
     * @return 数据权限
     */
    @Override
    public List<DhcDataAuth> selectDhcDataAuthByPage(DhcDataAuth dhcDataAuth)
    {   List<DhcDataAuth> list = dhcDataAuthMapper.selectDhcDataAuthByPage(dhcDataAuth);
        list.forEach(item->{
            String[] array = item.getDeptAllId().split("/");
            List<Long> deptIds = new ArrayList<>();
            for (String deptId : array) {
                deptIds.add(Long.valueOf(deptId));
            }
            item.setDeptIds(deptIds);
        });
        return list;
    }

    @Override
    public int insertDhcDataAuthBatch(List<DhcDataAuth> dhcDataAuthList)
    {
        int count = 0;
        for (DhcDataAuth dhcDataAuth : dhcDataAuthList) {
            count += insertDhcDataAuth(dhcDataAuth);
        }
        return count;
    }
}
