package com.ruoyi.dhc.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dhc.mapper.DhcProductPropertyValueMapper;
import com.ruoyi.dhc.domain.DhcProductPropertyValue;
import com.ruoyi.dhc.service.IDhcProductPropertyValueService;

/**
 * 产品属性取值Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-10-14
 */
@Service
public class DhcProductPropertyValueServiceImpl implements IDhcProductPropertyValueService 
{
    @Autowired
    private DhcProductPropertyValueMapper dhcProductPropertyValueMapper;

    /**
     * 查询产品属性取值
     * 
     * @param productPropertyId 产品属性取值主键
     * @return 产品属性取值
     */
    @Override
    public DhcProductPropertyValue selectDhcProductPropertyValueByProductPropertyId(Long productPropertyId)
    {
        return dhcProductPropertyValueMapper.selectDhcProductPropertyValueByProductPropertyId(productPropertyId);
    }

    /**
     * 查询产品属性取值列表
     * 
     * @param dhcProductPropertyValue 产品属性取值
     * @return 产品属性取值
     */
    @Override
    public List<DhcProductPropertyValue> selectDhcProductPropertyValueList(DhcProductPropertyValue dhcProductPropertyValue)
    {
        return dhcProductPropertyValueMapper.selectDhcProductPropertyValueList(dhcProductPropertyValue);
    }

    /**
     * 新增产品属性取值
     * 
     * @param dhcProductPropertyValue 产品属性取值
     * @return 结果
     */
    @Override
    public int insertDhcProductPropertyValue(DhcProductPropertyValue dhcProductPropertyValue)
    {
        dhcProductPropertyValue.setCreateTime(DateUtils.getNowDate());
        return dhcProductPropertyValueMapper.insertDhcProductPropertyValue(dhcProductPropertyValue);
    }

    /**
     * 修改产品属性取值
     * 
     * @param dhcProductPropertyValue 产品属性取值
     * @return 结果
     */
    @Override
    public int updateDhcProductPropertyValue(DhcProductPropertyValue dhcProductPropertyValue)
    {
        dhcProductPropertyValue.setUpdateTime(DateUtils.getNowDate());
        return dhcProductPropertyValueMapper.updateDhcProductPropertyValue(dhcProductPropertyValue);
    }

    /**
     * 批量删除产品属性取值
     * 
     * @param productPropertyIds 需要删除的产品属性取值主键
     * @return 结果
     */
    @Override
    public int deleteDhcProductPropertyValueByProductPropertyIds(Long[] productPropertyIds)
    {
        return dhcProductPropertyValueMapper.deleteDhcProductPropertyValueByProductPropertyIds(productPropertyIds);
    }

    /**
     * 删除产品属性取值信息
     * 
     * @param productPropertyId 产品属性取值主键
     * @return 结果
     */
    @Override
    public int deleteDhcProductPropertyValueByProductPropertyId(Long productPropertyId)
    {
        return dhcProductPropertyValueMapper.deleteDhcProductPropertyValueByProductPropertyId(productPropertyId);
    }
}
