package com.ruoyi.dhc.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dhc.mapper.DhcProductMapper;
import com.ruoyi.dhc.domain.DhcProduct;
import com.ruoyi.dhc.service.IDhcProductService;

/**
 * 产品信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-10-08
 */
@Service
public class DhcProductServiceImpl implements IDhcProductService 
{
    @Autowired
    private DhcProductMapper dhcProductMapper;

    /**
     * 查询产品信息
     * 
     * @param productId 产品信息主键
     * @return 产品信息
     */
    @Override
    public DhcProduct selectDhcProductByProductId(Long productId)
    {
        return dhcProductMapper.selectDhcProductByProductId(productId);
    }

    /**
     * 查询产品信息列表
     * 
     * @param dhcProduct 产品信息
     * @return 产品信息
     */
    @Override
    public List<DhcProduct> selectDhcProductList(DhcProduct dhcProduct)
    {
        return dhcProductMapper.selectDhcProductList(dhcProduct);
    }

    /**
     * 新增产品信息
     * 
     * @param dhcProduct 产品信息
     * @return 结果
     */
    @Override
    public int insertDhcProduct(DhcProduct dhcProduct)
    {
        dhcProduct.setCreateTime(DateUtils.getNowDate());
        return dhcProductMapper.insertDhcProduct(dhcProduct);
    }

    /**
     * 修改产品信息
     * 
     * @param dhcProduct 产品信息
     * @return 结果
     */
    @Override
    public int updateDhcProduct(DhcProduct dhcProduct)
    {
        dhcProduct.setUpdateTime(DateUtils.getNowDate());
        return dhcProductMapper.updateDhcProduct(dhcProduct);
    }

    /**
     * 批量删除产品信息
     * 
     * @param productIds 需要删除的产品信息主键
     * @return 结果
     */
    @Override
    public int deleteDhcProductByProductIds(Long[] productIds)
    {
        return dhcProductMapper.deleteDhcProductByProductIds(productIds);
    }

    /**
     * 删除产品信息信息
     * 
     * @param productId 产品信息主键
     * @return 结果
     */
    @Override
    public int deleteDhcProductByProductId(Long productId)
    {
        return dhcProductMapper.deleteDhcProductByProductId(productId);
    }
}
