-- ----------------------------
-- 1、产品信息表
-- ----------------------------
drop table if exists dhc_product;
create table dhc_product (
   product_id           bigint(20)      not null auto_increment    comment '产品id',
   product_line        varchar(32)     default ''                 comment '产品线编码',
   product_line_name        varchar(64)     default ''                 comment '产品线名称',
   project_num       varchar(32)     default ''                 comment '立项单号',
   Internal_model       varchar(32)     default ''                 comment '内部型号',
   product_category_large       varchar(32)     default ''                 comment '产品大类编码',
   product_category_middle       varchar(32)     default ''                 comment '产品中类编码',
   product_category_small       varchar(32)     default ''                 comment '产品小类编码',
   product_category       varchar(32)     default ''                 comment '产品品类',
   product_series       varchar(32)     default ''                 comment '产品系列',
   base_model       varchar(32)     default ''                 comment '基础型号',
   factory_model        varchar(32)     default ''                 comment '本厂型号',
   customer_model       varchar(32)     default ''                 comment '客户型号',
   brand_id       bigint(20)                   comment '品牌id',
   brand_name       varchar(64)     default ''                 comment '品牌名称',
   ir_datetime       datetime                     comment 'IR时间',
   dr_datetime       datetime                     comment 'DR时间',
   pack_way_code       varchar(32)     default ''                 comment '包装方式',
   product_net_weight       decimal(16,4)    default 0                 comment '净重',
   product_length       decimal(16,4)     default 0                 comment '产品尺寸-长',
   product_width       decimal(16,4)     default 0                 comment '产品尺寸-宽',
   product_height       decimal(16,4)     default 0                 comment '产品尺寸-高',
   loading_quantity_20GP       bigint(10)                      comment '装柜数量-20GP',
   loading_quantity_40GP       bigint(10)                      comment '装柜数量-40GP',
   loading_quantity_40HQ      bigint(10)                      comment '装柜数量-40HQ',
   min_order_quantity       bigint(10)                    comment '最小订单量',
   other_requirement       varchar(512)     default ''                 comment '其他要求',
   status       char(1)     default '0'                 comment '型号状态（0草稿 1在售 2下市 3冻结）',
   approve_status       char(1)     default '0'                 comment '审核状态（0审批中 1已通过 2已驳回）',
   del_flag          char(1)         default '0'                comment '删除标志（0代表存在 1代表删除）',
   create_by         varchar(64)     default ''                 comment '创建者',
   create_time 	    datetime                                   comment '创建时间',
   update_by         varchar(64)     default ''                 comment '更新者',
   update_time       datetime                                   comment '更新时间',
   primary key (product_id)
) engine=innodb auto_increment=1 comment = '产品信息表';

-- ----------------------------
-- 2、产品审核记录表
-- ----------------------------
drop table if exists dhc_product_approve_record;
create table dhc_product_approve_record (
  approve_record_id           bigint(20)      not null auto_increment    comment '区域id',
  product_id           bigint(20)      not null auto_increment    comment '产品id',
  approve_user_code         varchar(32)     default ''                 comment '审核人编码',
  approve_user_name         varchar(64)     default ''                 comment '审核人名称',
  approve_datetime         datetime     default ''                 comment '审核时间',
  approve_action         char(1)     default '0'                 comment '审核动作（0驳回 1通过）',
  approve_advice         varchar(512)          default ''                  comment '审核意见',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间',
  primary key (approve_record_id)
) engine=innodb auto_increment=1 comment = '产品审核记录表';


-- ----------------------------
-- 3、产品属性模板关联表
-- ----------------------------
drop table if exists dhc_product_property_table_rel;
create table dhc_product_property_table_rel (
  product_property_table_rel_id           bigint(20)      not null auto_increment primary key    comment '区域id',
  product_id           bigint(20)      not null comment '产品id',
  product_property_table_id           bigint(20)      not null comment '产品属性模板id',
  revision bigint(20) not null comment '使用的版本号',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间'
) engine=innodb auto_increment=1 comment = '产品属性模板关联表';


-- ----------------------------
-- 3、产品属性取值表
-- ----------------------------
drop table if exists dhc_product_property_value;
create table dhc_product_property_value (
  product_property_id           bigint(20)      not null auto_increment primary key    comment '区域id',
  product_id           bigint(20)      not null comment '产品id',
  group_name    varchar(100)    default '' comment '分组名称',
  property_name         varchar(64)     default ''                 comment '显示名称',
  property_type         varchar(32)     default ''                  comment '属性类型(INT,TEXT,ENUM,DATE)',
  property_dict_code     varchar(32)     default '' comment '属性关联数据字典CODE',
  field_name         varchar(32)     default ''                 comment '属性名称（字段英文标识符）',
  property_value        text               comment '属性值（以字符串形式存储）',
  property_value_name    varchar(200)     default ''         comment '属性显示名称（仅数据字典有效）',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间'
) engine=innodb auto_increment=1 comment = '产品属性取值表';



-- ----------------------------
-- 3、产品属性定义表
-- ----------------------------
drop table if exists dhc_product_property_def;
create table dhc_product_property_def (
  product_property_def_id           bigint(20)      not null auto_increment primary key    comment '属性定义ID',
  group_name varchar(100) default '' comment '分组名称',
  property_name         varchar(64)     default ''                 comment '属性名称',
  property_type         varchar(32)     default ''                  comment '属性类型(INT,TEXT,ENUM,DATE)',
  property_dict_code     varchar(32)     default '' comment '属性关联数据字典CODE',
  field_name         varchar(32)     default ''                 comment '字段名称（字段英文标识符，用于与外围系统交互）',
  memo         varchar(512)     default ''                  comment '备注',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间'
) engine=innodb auto_increment=1 comment = '产品属性定义表';


-- ----------------------------
-- 3、产品属性模板表
-- ----------------------------
drop table if exists dhc_product_property_table;
create table dhc_product_property_table (
  product_property_table_id           bigint(20)      not null auto_increment primary key    comment '区域id',
  display_name         varchar(64)     default ''                 comment '显示名称',
  head_revision      bigint(20)      not null comment '当前版本',
  group_json text comment '分组定义JSON',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间'
) engine=innodb auto_increment=1 comment = '产品属性模板表';



-- ----------------------------
-- 3、产品属性模板属性表
-- ----------------------------
drop table if exists dhc_product_property_table_detail;
create table dhc_product_property_table_detail (
  product_property_table_detail_id           bigint(20)      not null auto_increment primary key    comment '区域id',
  revision         bigint(20)      not null comment '版本号',
  group_name    varchar(100)    default '' comment '分组名称',
  property_index      int(11)      not null comment '属性排序',
  property_name         varchar(64)     default ''                 comment '显示名称',
  property_type         varchar(32)     default ''                  comment '属性类型(INT,TEXT,ENUM,DATE)',
  property_dict_code     varchar(32)     default '' comment '属性关联数据字典CODE',
  field_name         varchar(32)     default ''                 comment '属性名称（字段英文标识符）',
  memo         varchar(512)     default ''                  comment '备注',
  create_by         varchar(64)     default ''                 comment '创建者',
  create_time 	    datetime                                   comment '创建时间',
  update_by         varchar(64)     default ''                 comment '更新者',
  update_time       datetime                                   comment '更新时间'
) engine=innodb auto_increment=1 comment = '产品属性模板属性表';

